@@ -9,13 +9,13 @@
  * redistribution.
  */
 
+import org.gnome.gdk.Event;
 import org.gnome.gtk.Button;
 import org.gnome.gtk.FileChooser;
 import org.gnome.gtk.FileChooserAction;
 import org.gnome.gtk.FileChooserButton;
 import org.gnome.gtk.Gtk;
 import org.gnome.gtk.Label;
-import org.gnome.gtk.Object;
 import org.gnome.gtk.ReliefStyle;
 import org.gnome.gtk.VBox;
 import org.gnome.gtk.Widget;
@@ -50,7 +50,7 @@ public final class Experiment
         x = new VBox(false, 3);
 
         l = new Label("These Buttons\n" + "are made for\n" + "clicking.");
-        x.packStart(l);
+        x.packStart(l, true, true, 0);
 
         b = new Button("Change Me?");
         b.setLabel("Press Me!");
@@ -71,8 +71,8 @@ public final class Experiment
             }
         });
 
-        w.connect(new Window.DELETE() {
-            public boolean onDeleteEvent(Widget source, Object event) {
+        w.connect(new Window.DELETE_EVENT() {
+            public boolean onDeleteEvent(Widget source, Event event) {
                 System.out.println("I was deleted!");
                 Gtk.mainQuit();
                 return false;
